/**
 * this plugin provide function for news RTE toolbar
 *
 * @author bloiu
 * @since 4/26/2017.
 */

'use strict';

var H1_ELEMENT = 'h1';
var H2_ELEMENT = 'h2';
var H3_ELEMENT = 'h3';
var NORMAL_ELEMENT = 'p';
var UPDATE_CURSOR_DELAY_MILLISECONDS = 100;

var cursorPosition = -1;

(function () {
	CKEDITOR.plugins.add('spToolbar', {
		init: function (e) {
			requires : ['styles'],

			// register content change listener here.
			e.on('change', function () {
			    CkEditorJavaScriptBridge.contentChange(e.getData());
			});

			e.on('instanceReady', function () {
			    CkEditorJavaScriptBridge.onEditorReady();
			});

			e.on('dataReady', function () {
			    CkEditorJavaScriptBridge.onEditorReady();
			});

			e.on('selectionChange', function() {
			    setTimeout(function() {
			        updateCursorPosition(e);
			    }, UPDATE_CURSOR_DELAY_MILLISECONDS);
			});

			e.on('autoGrow', function() {
			    setTimeout(function() {
			        updateCursorPosition(e);
			    }, UPDATE_CURSOR_DELAY_MILLISECONDS);
			});

			e.on('afterAutoGrow', function() {
                CkEditorJavaScriptBridge.afterAutoGrow();
        	});

			e.on('blur', function() {
                cursorPosition = -1;
        	});

			// TODO bloiu: 1. check whether selected string already contains link
			// 2. check whether selected string contains multiple paragraph
			// if 1 || 2, function return do nothing.
			e.addCommand('addLink', {
				exec: function (editor) {
					var b = e.getSelection();
					var a = {};
					var c;
					var d;
					b = b.getRanges()[0];
					// if no text selected, we insert a new text with link address.
					if (b.collapsed) {
                        a = new CKEDITOR.dom.text(CkEditorJavaScriptBridge.getInputLinkAddress(), e.document), b.shrink(CKEDITOR.SHRINK_TEXT),
                        e.editable().extractHtmlFromRange(b), b.insertNode(a);
					}
					a = b._find("a");
					for (d = 0; d < a.length; d++) {
						a[d].remove(!0);
					}
					c = new CKEDITOR.style({
						element: "a",
						attributes: {'href': CkEditorJavaScriptBridge.getInputLinkAddress()}
					});
					c.type = CKEDITOR.STYLE_INLINE;
					c.applyToRange(b, editor);
					// select this range as the only one with CKEDITOR.dom.selection.selectRanges.
					b.select()
				}
			});

			e.addCommand('focus', {
				exec: function (editor) {
					editor.focus();
				}
			});

			e.addCommand('H1', {
				exec: function (editor) {
					applyHeaderSytle(editor, H1_ELEMENT);
				}
			});

			e.addCommand('H2', {
				exec: function (editor) {
					applyHeaderSytle(editor, H2_ELEMENT);
				}
			});

			e.addCommand('H3', {
				exec: function (editor) {
					applyHeaderSytle(editor, H3_ELEMENT);
				}
			});

			e.addCommand('H', {
				exec: function (editor) {
					applyHeaderSytle(editor, NORMAL_ELEMENT);
				}
			});

			e.addCommand('HeadingStatus', {
				exec: function (editor) {
					editor.focus();

					var style_h1 = new CKEDITOR.style({element: H1_ELEMENT});
					var style_h2 = new CKEDITOR.style({element: H2_ELEMENT});
					var style_h3 = new CKEDITOR.style({element: H3_ELEMENT});
					var elementPath = new CKEDITOR.dom.elementPath(editor.getSelection().getStartElement());

					// can not set state to 0-2 (default value)
					if (style_h1.checkActive(elementPath)) {
						this.setState(100);
					} else if (style_h2.checkActive(elementPath)) {
						this.setState(200);
					} else if (style_h3.checkActive(elementPath)) {
						this.setState(300);
					} else {
						this.setState(400);
					}
				}
			});

			function applyHeaderSytle(editor, tag) {
				editor.focus();
				var style = new CKEDITOR.style({element: tag});
				var elementPath = new CKEDITOR.dom.elementPath(editor.getSelection().getStartElement());
				style['apply'](editor.document);
			}

			function updateCursorPosition(editor) {
                var sel = editor.getSelection().getNative();
                if (sel && sel.focusNode) {
                    // Use the selection focus as the cursor position.
                    // Setting the range start and end to the end of the selection gives us the cursor position, this is because:
                    // 1. When there's a range selected the focus is where the user ended the selection.
                    // 2. When there's no range selected the focus is the cursor position.
                    var range = document.createRange();
                    range.setStart(sel.focusNode, sel.focusOffset);
                    range.setEnd(sel.focusNode, sel.focusOffset);
                    var rects = range.getClientRects();
                    var rect =  null;

                    if (rects && rects.length > 0) {
                        rect = rects[0];
                    } else {
                        // When the cursor is in an empty line range.GetClientRects() returns an empty array.
                        // Fallback to the rect containing the focus node.
                        rect = sel.focusNode.getBoundingClientRect();
                    }

                    if (rect) {
                        var newY = rect.top;
                        if (newY != cursorPosition) {
                            cursorPosition = newY;
                            CkEditorJavaScriptBridge.cursorPositionChanged(cursorPosition, rect.height);
                        }
                    }
                }
            }
		}
	});
})();